==> HostCMS.Free_6.7.tar.gz: modules/shop/exchange/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'!download' => '-- Not upload --',
	'group_id' => 'Section IS',
	'group_name' => 'Section name',
	'group_path' => 'Section path',
	'group_sorting' => "Group sorting order",
	'group_description' => 'Section description',
	'group_seo_title' => "Group title",
	'group_seo_description' => "Group description",
	'group_seo_keywords' => "Group keywords",
	'group_image_large' => 'Product image file',
	'group_image_small' => 'Small image file for product',
	'group_guid' => 'CommerceML products group identifier',
	'parent_group_guid' => 'CommerceML products parent group identifier',
	'currency_id' => 'Currency ID',
	'tax_id' => 'Product tax IS',
	'producer_id' => 'Manufacturer ID',
	'producer_name' => 'Name of manufacturer',
	'seller_id' => 'Seller ID',
	'seller_name' => 'Name of seller',
	'measure_id' => 'Measurement unit ID',
	'measure_value' => 'Name of measurement unit',
	'item_id' => 'Product ID',
	'item_name' => 'Product name',
	'item_datetime' => 'Date',
	'item_marking' => 'Marking of goods',
	'item_description' => 'Product description',
	'item_text' => 'Product text',
	'item_image_large' => 'Product image file',
	'item_image_small' => 'Small image file for product',
	'item_tags' => 'Tags',
	'item_weight' => 'Product weight',
	'item_length' => 'Lenght',
	'item_width' => 'Width',
	'item_height' => 'Height',
	'item_price' => 'Product price',
	'item_active' => 'Product activity',
	'item_sorting' => 'Product sorting order',
	'item_path' => 'Path to product',
	'item_seo_title' => 'Meta element title',
	'item_seo_description' => 'Meta element description',
	'item_seo_keywords' => 'Meta element keywords',
	'item_indexing' => 'Index checkbox',
	'item_yandex_market' => 'Checkbox "Export to Yandex.Market"',
	'item_yandex_market_bid' => 'Yandex.Market base charge',
	'item_yandex_market_cid' => 'Yandex.Market charge for model cards',
	
	'item_yandex_market_manufacturer_warranty' => 'Manufacturer warranty',
	'item_yandex_market_vendorcode' => 'Vendor Code',
	'item_yandex_market_country_of_origin' => 'Country of origin',
	
	'item_parent_marking' => 'Parent\'s marking for modifications',
	'item_parent_guid' => 'Parent\'s CommerceML for modifications',
	'digital_item_value' => "Text of digital product",
	'digital_item_filename' => "File of digital product",
	'digital_item_count' => "Count of digital product",
	'item_end_datetime' => '<acronym title="Completion date of product publishing">Completion date of publication</acronym>',
	'item_start_datetime' => '<acronym title="Date of product publication">Publication date</acronym>',
	'item_type' => 'Product type',
	'item_additional_group' => "Shortcute's GUID",
	'specialprices_min_quantity' => "Count from",
	'specialprices_max_quantity' => "Count to",
	'specialprices_price' => "Price value",
	'specialprices_percent' => "Percentage from price",
	'item_guid' => "CommerceML product identifier",
	'group_active' => "Group activity",

	'siteuser_id' => "Siteuser ID",
	'digital_item_name' => "Digital Item Name",
	'item_yandex_market_sales_notes' => "Sales notes",
	'item_parent_associated' => "Associated item, Parent Item Marking",
	'item_associated_markings' => "Associated item's margings",

	'order_guid' => "Order GUID",
	'order_number' => "Order number",
	'order_country' => "Country",
	'order_location' => "Location",
	'order_city' => "City",
	'order_city_area' => "District",
	'order_name' => "Customer's name",
	'order_surname' => "Customer's surname",
	'order_patronymic' => "Customer's patronymic",
	'order_email' => "Customer's email",
	'order_akt' => "Acceptance report",
	'order_schet_fak' => "Vat invoice",
	'order_company_name' => "Company",
	'order_inn' => "TIN",
	'order_kpp' => "KPP",
	'order_phone' => "Phone",
	'order_fax' => "Fax",
	'order_address' => "Address",
	'order_order_status' => "Order status",
	'order_currency' => "Order currency",
	'order_payment_system_id' => "Payment system ID",
	'order_date' => "Order date",
	'order_pay_status' => "Order pay status",
	'order_pay_date' => "Order pay date",
	'order_description' => "Order description",
	'order_info' => "Order info",
	'order_canceled' => "Order canceled",
	'order_pay_status_change_date' => "Date os status change for order",
	'order_delivery_info' => "Delivery info",
	'order_item_marking' => "Mark of order's item",
	'order_item_name' => "Name of order's item",
	'order_item_quantity' => "Count of order's item",
	'order_item_price' => "Price of order's item",
	'order_item_rate' => "Tax of order's item",
	'order_item_type' => "Type of order's item"
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/exchange/i18n/en.php <==
<?php

return array(
	'!download' => '-- Not upload --',
	'group_id' => 'Section IS',
	'group_name' => 'Section name',
	'group_path' => 'Section path',
	'group_sorting' => "Group sorting order",
	'group_description' => 'Section description',
	'group_seo_title' => "Group title",
	'group_seo_description' => "Group description",
	'group_seo_keywords' => "Group keywords",
	'group_image_large' => 'Product image file',
	'group_image_small' => 'Small image file for product',
	'group_guid' => 'CommerceML products group identifier',

	'group_seo_group_title_template' => 'Group title template',
	'group_seo_group_description_template' => 'Group description template',
	'group_seo_group_keywords_template' => 'Group keywords template',

	'group_seo_item_title_template' => 'Product title template',
	'group_seo_item_description_template' => 'Product description template',
	'group_seo_item_keywords_template' => 'Product keywords template',
	
	'parent_group_guid' => 'CommerceML products parent group identifier',
	'currency_id' => 'Currency ID',
	'tax_id' => 'Product tax IS',
	'producer_id' => 'Manufacturer ID',
	'producer_name' => 'Name of manufacturer',
	'seller_id' => 'Seller ID',
	'seller_name' => 'Name of seller',
	'measure_id' => 'Measurement unit ID',
	'measure_value' => 'Name of measurement unit',
	'item_id' => 'Product ID',
	'item_name' => 'Product name',
	'item_datetime' => 'Date',
	'item_marking' => 'Marking of goods',
	'item_description' => 'Product description',
	'item_text' => 'Product text',
	'item_image_large' => 'Large image',
	'item_image_small' => 'Small image',
	'item_tags' => 'Tags',
	'item_weight' => 'Weight',
	'item_length' => 'Lenght',
	'item_width' => 'Width',
	'item_height' => 'Height',
	'item_min_quantity' => 'Min quantity',
	'item_max_quantity' => 'Max quantity',
	'item_quantity_step' => 'Step',
	'item_yandex_vendorcode' => 'vendorCode',
	'item_price' => 'Product price',
	'item_active' => 'Product activity',
	'item_sorting' => 'Product sorting order',
	'item_path' => 'Path to item',
	'item_full_path' => 'Full path to item',
	'item_seo_title' => 'Meta element title',
	'item_seo_description' => 'Meta element description',
	'item_seo_keywords' => 'Meta element keywords',
	'item_indexing' => 'Index checkbox',
	'item_yandex_market' => 'Checkbox "Export to Yandex.Market"',
	'item_yandex_market_bid' => 'Yandex.Market base charge',
	'item_yandex_market_cid' => 'Yandex.Market charge for model cards',

	'item_yandex_market_manufacturer_warranty' => 'Manufacturer warranty',
	'item_yandex_market_vendorcode' => 'Vendor Code',
	'item_yandex_market_country_of_origin' => 'Country of origin',

	'item_parent_marking' => 'Parent\'s marking for modifications',
	'item_parent_guid' => 'Parent\'s CommerceML for modifications',
	'digital_item_value' => "Text of digital product",
	'digital_item_filename' => "File of digital product",
	'digital_item_count' => "Count of digital product",
	'item_end_datetime' => '<acronym title="Completion date of product publishing">Completion date of publication</acronym>',
	'item_start_datetime' => '<acronym title="Date of product publication">Publication date</acronym>',
	'item_type' => 'Product type',
	'item_additional_group' => "Shortcute's GUID",
	'item_barcode' => "Barcodes",
	'item_sets_guid' => 'Goods in the set (by GUID)',
	'item_sets_marking' => 'Goods in the set (by Marking)',
	'specialprices_min_quantity' => "Count from",
	'specialprices_max_quantity' => "Count to",
	'specialprices_price' => "Price value",
	'specialprices_percent' => "Percentage from price",
	'item_guid' => "CommerceML product identifier",
	'group_active' => "Group activity",

	'siteuser_id' => "Client ID",
	'digital_item_name' => "Digital Item Name",
	'item_yandex_market_sales_notes' => "Sales Notes",
	'item_parent_associated' => "Associated Goods, Parent Goods Marking",
	'item_associated_markings' => "Associated Goods's margings",
	'item_tabs' => "Tabs of Goods",
	'caption_modifications' => "Modifications by Properties",
	'modification_by_property' => "Modifications by %s",

	'order_guid' => "Order GUID",
	'order_number' => "Order number",
	'order_country' => "Country",
	'order_location' => "Location",
	'order_city' => "City",
	'order_city_area' => "District",
	'order_name' => "Customer's name",
	'order_surname' => "Customer's surname",
	'order_patronymic' => "Customer's patronymic",
	'order_email' => "Customer's email",
	'order_akt' => "Acceptance report",
	'order_schet_fak' => "Vat invoice",
	'order_company_name' => "Company",
	'order_inn' => "TIN",
	'order_kpp' => "KPP",
	'order_phone' => "Phone",
	'order_fax' => "Fax",
	'order_address' => "Address",
	'order_order_status' => "Order status",
	'order_currency' => "Order currency",
	'order_payment_system_id' => "Payment system ID",
	'order_date' => "Order date",
	'order_pay_status' => "Order pay status",
	'order_pay_date' => "Order pay date",
	'order_description' => "Order description",
	'order_info' => "Order info",
	'order_canceled' => "Order canceled",
	'order_pay_status_change_date' => "Date os status change for order",
	'order_delivery_info' => "Delivery info",
	'order_item_marking' => "Mark of order's item",
	'order_item_name' => "Name of order's item",
	'order_item_quantity' => "Count of order's item",
	'order_item_price' => "Price of order's item",
	'order_item_rate' => "Tax of order's item",
	'order_item_type' => "Type of order's item",
	'shop_warehouse_inventory' => "Inventory by importing goods",
	'shop_price_setting' => "Set prices by importing goods",
);
